@@ -2,7 +2,7 @@ package App::Netdisco::Util::Device;
 
 use Dancer qw/:syntax :script/;
 use Dancer::Plugin::DBIC 'schema';
-use App::Netdisco::Util::Permission qw/check_acl_no check_acl_only/;
+use App::Netdisco::Util::Permission qw/acl_matches acl_matches_only/;
 
 use File::Spec::Functions qw(catdir catfile);
 use File::Path 'make_path';
@@ -77,7 +77,7 @@ Returns true if the transaction completes, else returns false.
 =cut
 
 sub delete_device {
-  my ($ip, $archive, $log) = @_;
+  my ($ip, $archive) = @_;
   my $device = get_device($ip) or return 0;
   return 0 if not $device->in_storage;
 
@@ -87,13 +87,6 @@ sub delete_device {
     schema(vars->{'tenant'})->resultset('Device')
       ->search({ ip => $device->ip })->delete({archive_nodes => $archive});
 
-    schema(vars->{'tenant'})->resultset('UserLog')->create({
-      username => session('logged_in_user'),
-      userip => scalar eval {request->remote_address},
-      event => (sprintf "Delete device %s", $device->ip),
-      details => $log,
-    });
-
     $happy = 1;
   });
 
@@ -191,10 +184,10 @@ sub is_discoverable {
     if (match_to_setting($remote_type, 'discover_no_type'));
 
   return _bail_msg("is_discoverable: $device matched discover_no")
-    if check_acl_no($device, 'discover_no');
+    if acl_matches($device, 'discover_no');
 
   return _bail_msg("is_discoverable: $device failed to match discover_only")
-    unless check_acl_only($device, 'discover_only');
+    unless acl_matches_only($device, 'discover_only');
 
   return 1;
 }
@@ -243,14 +236,14 @@ sub is_arpnipable {
 
   return _bail_msg("is_arpnipable: $device has no layer 3 capability")
     if ($device->in_storage() and not ($device->has_layer(3)
-                                       or check_acl_no($device, 'force_arpnip')
-                                       or check_acl_no($device, 'ignore_layers')));
+                                       or acl_matches($device, 'force_arpnip')
+                                       or acl_matches($device, 'ignore_layers')));
 
   return _bail_msg("is_arpnipable: $device matched arpnip_no")
-    if check_acl_no($device, 'arpnip_no');
+    if acl_matches($device, 'arpnip_no');
 
   return _bail_msg("is_arpnipable: $device failed to match arpnip_only")
-    unless check_acl_only($device, 'arpnip_only');
+    unless acl_matches_only($device, 'arpnip_only');
 
   return 1;
 }
@@ -299,17 +292,17 @@ sub is_macsuckable {
 
   return _bail_msg("is_macsuckable: $device has no layer 2 capability")
     if ($device->in_storage() and not ($device->has_layer(2)
-                                       or check_acl_no($device, 'force_macsuck')
-                                       or check_acl_no($device, 'ignore_layers')));
+                                       or acl_matches($device, 'force_macsuck')
+                                       or acl_matches($device, 'ignore_layers')));
 
   return _bail_msg("is_macsuckable: $device matched macsuck_no")
-    if check_acl_no($device, 'macsuck_no');
+    if acl_matches($device, 'macsuck_no');
 
   return _bail_msg("is_macsuckable: $device matched macsuck_unsupported")
-    if check_acl_no($device, 'macsuck_unsupported');
+    if acl_matches($device, 'macsuck_unsupported');
 
   return _bail_msg("is_macsuckable: $device failed to match macsuck_only")
-    unless check_acl_only($device, 'macsuck_only');
+    unless acl_matches_only($device, 'macsuck_only');
 
   return 1;
 }
